Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(313)

Unified Diff: runtime/vm/object.cc

Issue 2537253002: Fixed assert causing crash when attempting to load a library from an invalid path. (Closed)
Patch Set: Addressed comments from initial upload Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/language/vm/regress_27201_lib.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.cc
diff --git a/runtime/vm/object.cc b/runtime/vm/object.cc
index 428dfa34b299bd70cb87a437ba5eca91c0c33fa3..ac586d969d51a2109635fb419c67c781803cafd7 100644
--- a/runtime/vm/object.cc
+++ b/runtime/vm/object.cc
@@ -11008,8 +11008,8 @@ bool LibraryPrefix::LoadLibrary() const {
Exceptions::PropagateError(Error::Cast(obj));
}
} else {
- // Another load request is in flight.
- ASSERT(deferred_lib.LoadRequested());
+ // Another load request is in flight or previously failed.
+ ASSERT(deferred_lib.LoadRequested() || deferred_lib.LoadFailed());
}
return false; // Load request not yet completed.
}
« no previous file with comments | « no previous file | tests/language/vm/regress_27201_lib.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698